pub enum SpecialVersion {
Alpha,
Alpha2,
Beta,
}Expand description
SpecialVersion represents a special version from the first releases.
Before Rust 1.0.0, there were two alpha and one beta release, namely
1.0.0-alpha1.0.0-alpha.21.0.0-beta
This enum represents those releases.
Variants